@@ -9,7 +9,7 @@ from jenkinsflow import flow
 from jenkinsflow.api_base import AuthError
 
 from .framework import api_select
-from .cfg import ApiType
+from .framework.cfg import ApiType
 
 
 @pytest.mark.not_apis(ApiType.MOCK, ApiType.SCRIPT)
@@ -20,5 +20,6 @@ def test_auth_error(api_type):
             with flow.serial(api, timeout=70, job_name_prefix=api.job_name_prefix) as ctrl1:
                 ctrl1.invoke('j11')
 
-        assert ("401 Client Error: Invalid password/token for user: noaccess for url: http://" in str(exinfo.value) or
+        assert ("401 Client Error: Unauthorized for url: http://" in str(exinfo.value) or
+                "401 Client Error: Invalid password/token for user: noaccess for url: http://" in str(exinfo.value) or
                 "401 Unauthorized user: 'noaccess' for url: http://" in str(exinfo.value))
