@@ -3,10 +3,10 @@
 
 import pytest
 
-from jenkinsflow.flow import serial, FailedChildJobException, FailedChildJobsException
+from jenkinsflow.flow import serial
 
 from .framework import api_select
-from .cfg import ApiType
+from .framework.cfg import ApiType
 
 
 def _job_name(api, short_name):
