@@ -1,9 +1,9 @@
 import time as real_time
 
 
-class HyperSpeed(object):
+class HyperSpeed():
     def __init__(self, speedup, **kwargs):
-        super(HyperSpeed, self).__init__()
+        super().__init__()
         assert isinstance(speedup, int)
         self.speedup = speedup
 
