@@ -1,10 +1,7 @@
 # Copyright (c) 2012 - 2017 Lars Hupfeldt Nielsen, Hupfeldt IT
 # All rights reserved. This work is under a BSD license, see LICENSE.TXT.
 
-from __future__ import print_function
-
 import sys
-import time
 import datetime
 
 
