@@ -8,5 +8,5 @@ from jenkinsflow import jenkins_api
 
 def test_jenkins_api_init_api_no_password(api_type):
     with raises(Exception) as exinfo:
-        jenkins_api.Jenkins("dummy", "dummy", username="hugo")
+        jenkins_api.JenkinsApi("dummy", "dummy", username="hugo")
     assert "You must specify both username and password or neither" in str(exinfo.value)
