@@ -1,13 +1,12 @@
 # Copyright (c) 2012 - 2015 Lars Hupfeldt Nielsen, Hupfeldt IT
 # All rights reserved. This work is under a BSD license, see LICENSE.TXT.
 
-import re
 import pytest
 
-from jenkinsflow.flow import parallel, serial, FailedChildJobException, FailedChildJobsException
+from jenkinsflow.flow import parallel
+
 from .framework import api_select
-from .framework.utils import lines_in
-from .cfg import ApiType
+from .framework.cfg import ApiType
 
 
 @pytest.mark.not_apis(ApiType.MOCK)
@@ -39,5 +38,3 @@ def test_replace_invocation_class_log_override(api_type, capsys):
 
         sout, _ = capsys.readouterr()
         assert "HELLO LOG" in sout
-
-
