@@ -1,8 +1,6 @@
 # Copyright (c) 2012 - 2015 Lars Hupfeldt Nielsen, Hupfeldt IT
 # All rights reserved. This work is under a BSD license, see LICENSE.TXT.
 
-from __future__ import print_function
-
 import os
 
 import pytest
@@ -10,7 +8,7 @@ import pytest
 from jenkinsflow.flow import serial
 
 from .framework import api_select
-from .cfg import ApiType
+from .framework.cfg import ApiType
 
 
 @pytest.mark.apis(ApiType.SCRIPT)
@@ -27,8 +25,8 @@ def test_script_api_env_unchanged(api_type):
         with serial(api, timeout=70, job_name_prefix=api.job_name_prefix, report_interval=1) as ctrl1:
             ctrl1.invoke(job_name)
 
-        # Do a few more things to 
+        # Do a few more things to
         job = api.get_job(api.job_name_prefix + job_name)
-        _, _, build_num = job.job_status()
+        _, _, _ = job.job_status()
 
     assert os.environ == env_before
